[kde-doc-english] [kde-baseapps] /: Rename "Recently Accessed" to "Recently Saved"

Emmanuel Pescosta emmanuelpescosta099 at gmail.com
Tue Sep 2 19:41:37 UTC 2014


Git commit 072c5e06cee89049ddc1553a6a21b84a0dcac0f1 by Emmanuel Pescosta, on behalf of kdeuser 56.
Committed on 02/09/2014 at 19:37.
Pushed by emmanuelp into branch 'master'.

Rename "Recently Accessed" to "Recently Saved"

In dolphin the Section that leads you to timeline claims
to show "Recently Accessed", which is not true, it shows
"Recently Saved" instead.

BUG: 304854
REVIEW: 119986

M  +6    -6    doc/dolphin/index.docbook
M  +9    -9    dolphin/src/panels/places/placesitem.cpp
M  +1    -1    dolphin/src/panels/places/placesitem.h
M  +14   -14   dolphin/src/panels/places/placesitemmodel.cpp
M  +1    -1    dolphin/src/panels/places/placespanel.cpp

http://commits.kde.org/kde-baseapps/072c5e06cee89049ddc1553a6a21b84a0dcac0f1

diff --git a/doc/dolphin/index.docbook b/doc/dolphin/index.docbook
index 5fe85f5..d05fa49 100644
--- a/doc/dolphin/index.docbook
+++ b/doc/dolphin/index.docbook
@@ -192,7 +192,7 @@ The <link linkend="places-panel"><guilabel>Places</guilabel> panel</link>, which
 provides quick access to bookmarked locations and disks or other media.
 </para>
 <para>If desktop search and file indexing are enabled in the <guilabel>Desktop Search</guilabel> 
-module in the &systemsettings; the panel provides <guilabel>Recently Accessed</guilabel> 
+module in the &systemsettings; the panel provides <guilabel>Recently Saved</guilabel> 
 items and allows you to search for <guilabel>Documents</guilabel>, <guilabel>Images</guilabel>,
 <guilabel>Audio Files</guilabel> and <guilabel>Video</guilabel>.
 </para></listitem>
@@ -690,7 +690,7 @@ to a different position, even outside the window.
 <title>Places</title>
 <!--FIXME difference between places panel in dolphin + kde filedialog + konqueror:
 context menu Icon Size? No different entries ?-->
-<!--Four groups: Places = Folders, Devices, with Nepomuk Recently Accessed and Search For -->
+<!--Four groups: Places = Folders, Devices, with Baloo Recently Saved and Search For -->
 <para>
 The <guilabel>Places</guilabel> panel is located at the left of the window by
 default. The <guilabel>Places</guilabel> panel shows any locations you have
@@ -800,10 +800,10 @@ Start to type into the find input box and the search starts immediately.
 (<userinput>*foo*</userinput> and <userinput>foo</userinput> are equivalent), 
 but you can use wildcards inside the search term. <userinput>*</userinput> will match 
 zero or more characters, <userinput>?</userinput> only one single character.</para>
-<para>This feature can be used with running Nepomuk/Strigi services; without these services
+<para>This feature can be used with running Baloo services; without these services
 a KIOSlave is launched to provide the search results.</para>
-<para>The option from <guilabel>Everywhere</guilabel> with activated Nepomuk/Strigi 
-services searches in all indexed folders, without Nepomuk/Strigi this option  
+<para>The option from <guilabel>Everywhere</guilabel> with activated Baloo 
+services searches in all indexed folders, without Baloo this option  
 starts the search from the user's <replaceable>Home</replaceable> folder.</para>
 
 <screenshot>
@@ -828,7 +828,7 @@ the user to shrink the number of search results.</para>
   a time period and rating<!--FIXME readd when again implemented: and tag, if you have defined any.--></para>
 
 <para>Alternatively you can use these options in the <guilabel>Places</guilabel> panel 
-together with the <guilabel>Filter</guilabel> bar to find files using Nepomuk or limit 
+together with the <guilabel>Filter</guilabel> bar to find files using Baloo or limit 
 the search to files matching the filter expression.</para>
 
 </sect2>
diff --git a/dolphin/src/panels/places/placesitem.cpp b/dolphin/src/panels/places/placesitem.cpp
index 539b926..173da29 100644
--- a/dolphin/src/panels/places/placesitem.cpp
+++ b/dolphin/src/panels/places/placesitem.cpp
@@ -144,20 +144,20 @@ void PlacesItem::setBookmark(const KBookmark& bookmark)
     const GroupType type = groupType();
     if (icon().isEmpty()) {
         switch (type) {
-        case RecentlyAccessedType: setIcon("chronometer"); break;
-        case SearchForType:        setIcon("nepomuk"); break;
+        case RecentlySavedType: setIcon("chronometer"); break;
+        case SearchForType:     setIcon("nepomuk"); break;
         case PlacesType:
-        default:                   setIcon("folder");
+        default:                setIcon("folder");
         }
 
     }
 
     switch (type) {
-    case PlacesType:           setGroup(i18nc("@item", "Places")); break;
-    case RecentlyAccessedType: setGroup(i18nc("@item", "Recently Accessed")); break;
-    case SearchForType:        setGroup(i18nc("@item", "Search For")); break;
-    case DevicesType:          setGroup(i18nc("@item", "Devices")); break;
-    default:                   Q_ASSERT(false); break;
+    case PlacesType:        setGroup(i18nc("@item", "Places")); break;
+    case RecentlySavedType: setGroup(i18nc("@item", "Recently Saved")); break;
+    case SearchForType:     setGroup(i18nc("@item", "Search For")); break;
+    case DevicesType:       setGroup(i18nc("@item", "Devices")); break;
+    default:                Q_ASSERT(false); break;
     }
 
     setHidden(bookmark.metaDataItem("IsHidden") == QLatin1String("true"));
@@ -173,7 +173,7 @@ PlacesItem::GroupType PlacesItem::groupType() const
     if (udi().isEmpty()) {
         const QString protocol = url().protocol();
         if (protocol == QLatin1String("timeline")) {
-            return RecentlyAccessedType;
+            return RecentlySavedType;
         }
 
         if (protocol.contains(QLatin1String("search"))) {
diff --git a/dolphin/src/panels/places/placesitem.h b/dolphin/src/panels/places/placesitem.h
index 297f12d..4c636ec 100644
--- a/dolphin/src/panels/places/placesitem.h
+++ b/dolphin/src/panels/places/placesitem.h
@@ -44,7 +44,7 @@ public:
     {
         PlacesType,
         SearchForType,
-        RecentlyAccessedType,
+        RecentlySavedType,
         DevicesType
     };
 
diff --git a/dolphin/src/panels/places/placespanel.cpp b/dolphin/src/panels/places/placespanel.cpp
index f19fa1e..720e07c 100644
--- a/dolphin/src/panels/places/placespanel.cpp
+++ b/dolphin/src/panels/places/placespanel.cpp
@@ -335,7 +335,7 @@ void PlacesPanel::slotItemDropEvent(int index, QGraphicsSceneDragDropEvent* even
 
     const PlacesItem* destItem = m_model->placesItem(index);
     const PlacesItem::GroupType group = destItem->groupType();
-    if (group == PlacesItem::SearchForType || group == PlacesItem::RecentlyAccessedType) {
+    if (group == PlacesItem::SearchForType || group == PlacesItem::RecentlySavedType) {
         return;
     }
 


More information about the kde-doc-english mailing list
diff --git a/dolphin/src/panels/places/placesitemmodel.cpp b/dolphin/src/panels/places/placesitemmodel.cpp
index dc2b95c..d906118 100644
--- a/dolphin/src/panels/places/placesitemmodel.cpp
+++ b/dolphin/src/panels/places/placesitemmodel.cpp
@@ -58,7 +58,7 @@
 
 namespace {
     // As long as KFilePlacesView from kdelibs is available in parallel, the
     // system-bookmarks for "Recently Accessed" and "Search For" should be
     // shown only inside the Places Panel. This is necessary as the stored
     // URLs needs to get translated to a Baloo-search-URL on-the-fly to
     // be independent from changes in the Baloo-search-URL-syntax.
@@ -741,7 +741,7 @@ void PlacesItemModel::loadBookmarks()
     // items should always be collected in one group so the items are collected first
     // in separate lists before inserting them.
     QList<PlacesItem*> placesItems;
-    QList<PlacesItem*> recentlyAccessedItems;
+    QList<PlacesItem*> recentlySavedItems;
     QList<PlacesItem*> searchForItems;
     QList<PlacesItem*> devicesItems;
 
@@ -766,11 +766,11 @@ void PlacesItemModel::loadBookmarks()
                 }
 
                 switch (item->groupType()) {
-                case PlacesItem::PlacesType:           placesItems.append(item); break;
-                case PlacesItem::RecentlyAccessedType: recentlyAccessedItems.append(item); break;
-                case PlacesItem::SearchForType:        searchForItems.append(item); break;
+                case PlacesItem::PlacesType:        placesItems.append(item); break;
+                case PlacesItem::RecentlySavedType: recentlySavedItems.append(item); break;
+                case PlacesItem::SearchForType:     searchForItems.append(item); break;
                 case PlacesItem::DevicesType:
-                default:                               Q_ASSERT(false); break;
+                default:                            Q_ASSERT(false); break;
                 }
             }
         }
@@ -785,11 +785,11 @@ void PlacesItemModel::loadBookmarks()
             if (missingSystemBookmarks.contains(data.url)) {
                 PlacesItem* item = createSystemPlacesItem(data);
                 switch (item->groupType()) {
-                case PlacesItem::PlacesType:           placesItems.append(item); break;
-                case PlacesItem::RecentlyAccessedType: recentlyAccessedItems.append(item); break;
-                case PlacesItem::SearchForType:        searchForItems.append(item); break;
+                case PlacesItem::PlacesType:        placesItems.append(item); break;
+                case PlacesItem::RecentlySavedType: recentlySavedItems.append(item); break;
+                case PlacesItem::SearchForType:     searchForItems.append(item); break;
                 case PlacesItem::DevicesType:
-                default:                               Q_ASSERT(false); break;
+                default:                            Q_ASSERT(false); break;
                 }
             }
         }
@@ -803,7 +803,7 @@ void PlacesItemModel::loadBookmarks()
 
     QList<PlacesItem*> items;
     items.append(placesItems);
-    items.append(recentlyAccessedItems);
+    items.append(recentlySavedItems);
     items.append(searchForItems);
     items.append(devicesItems);
 
@@ -848,7 +848,7 @@ PlacesItem* PlacesItemModel::createSystemPlacesItem(const SystemBookmarkData& da
     const QString protocol = data.url.protocol();
     if (protocol == QLatin1String("timeline") || protocol == QLatin1String("search")) {
         // As long as the KFilePlacesView from kdelibs is available, the system-bookmarks
         // for "Recently Accessed" and "Search For" should be a setting available only
         // in the Places Panel (see description of AppNamePrefix for more details).
         const QString appName = KGlobal::mainComponent().componentName() + AppNamePrefix;
         bookmark.setMetaDataItem("OnlyInApp", appName);
@@ -857,11 +857,11 @@ PlacesItem* PlacesItemModel::createSystemPlacesItem(const SystemBookmarkData& da
     PlacesItem* item = new PlacesItem(bookmark);
     item->setSystemItem(true);
 
     // Create default view-properties for all "Search For" and "Recently Accessed" bookmarks
     // in case if the user has not already created custom view-properties for a corresponding
     // query yet.
     const bool createDefaultViewProperties = (item->groupType() == PlacesItem::SearchForType ||
-                                              item->groupType() == PlacesItem::RecentlyAccessedType) &&
+                                              item->groupType() == PlacesItem::RecentlySavedType) &&
                                               !GeneralSettings::self()->globalViewProps();
     if (createDefaultViewProperties) {
         ViewProperties props(convertedUrl(data.url));
@@ -58,7 +58,7 @@
 namespace {
     // As long as KFilePlacesView from kdelibs is available in parallel, the
-    // system-bookmarks for "Recently Accessed" and "Search For" should be
+    // system-bookmarks for "Recently Saved" and "Search For" should be
     // shown only inside the Places Panel. This is necessary as the stored
     // URLs needs to get translated to a Baloo-search-URL on-the-fly to
@@ -848,7 +848,7 @@ PlacesItem* PlacesItemModel::createSystemPlacesItem(const SystemBookmarkData& da
     if (protocol == QLatin1String("timeline") || protocol == QLatin1String("search")) {
         // As long as the KFilePlacesView from kdelibs is available, the system-bookmarks
-        // for "Recently Accessed" and "Search For" should be a setting available only
+        // for "Recently Saved" and "Search For" should be a setting available only
         // in the Places Panel (see description of AppNamePrefix for more details).
         const QString appName = KGlobal::mainComponent().componentName() + AppNamePrefix;
@@ -857,11 +857,11 @@ PlacesItem* PlacesItemModel::createSystemPlacesItem(const SystemBookmarkData& da
     item->setSystemItem(true);
 
-    // Create default view-properties for all "Search For" and "Recently Accessed" bookmarks
+    // Create default view-properties for all "Search For" and "Recently Saved" bookmarks
     // in case if the user has not already created custom view-properties for a corresponding
     // query yet.